% This is the F.C. Donders Cente MEG/EEG analysis framework.
% It contains high-level Matlab functions that you can use to
% construct a complete analysis protocol.
% 
% PREPROCESSING         reading and preprocessing of EEG/MEG data
% DEFINETRIAL           is called by preprocessing
% REJECTARTIFACT        is caleld by preprocessing
% CHANNELSELECTION      explains how to select channels
% CHANNELCOMBINATION    explains how to select channel combinations
% RESAMPLEDATA          performs resampling of raw data
%
% FREQANALYSIS          frequency and timefrequency analysis
% FRQANAJACKSTATISTIC   coherence and frequency statistics
% POWERANALYSIS         very simple frequency analysis
% TIMELOCKANALYSIS      compute event-related fields
% TIMELOCKGRANDAVERAGE  average ERFs over multiple subjects
% TIMELOCKSTATISTICS    statistics for grand averaged ERFs
% COMPONENTANALYSIS     independent and principal component analysis
%
% SOURCEANANALYSIS      beamformer analysis (SAM, DICS)
% SOURCESTATISTICS      source parameter statistics based on resampling
% SOURCEDESCRIPTIVES    postprocessing of source reconstruction
% SOURCEINTERPOLATE     interpolation and alignment with anatomical MRI
% SOURCEWRITE           export source reconstruction to SPM or BrainVoyager
% SOURCEPLOT            3D visualisation of anatomy and source reconstruction
% SLICEINTERP           2D visualisation of anatomy and source reconstruction
%
% COMBINEPLANAR         compute magnitude from planar gradients
% MEGINTERPOLATE        interpolation to template gradiometer positions
%                       and planar gradient computation
%
% Copyrights (C) 2003-2004, F.C. Donders Centre, University Nijmegen
% Copyrights (C) 2003-2004, Center for Sensory Motor Interaction, University Aalborg
%
% Unauthorised copying and distribution is not allowed!
%
% The functions in this toolbox are copyrighted by their authors:
%   Robert Oostenveld, FCDC, SMI
%   Pascal Fries, FCDC
%   Jan-Matthijs Schoffelen, FCDC
%   Markus Bauer, FCDC
%   Ole Jensen, FCDC
%   Markus Siegel, FCDC, UKE Hamburg
%   Jens Schwarzbach, FCDC
%
% The framework depend on functions from other toolboxes to do a large
% part of the actual work, such as reading data from binary files and
% forward and inverse modelling of the EEG/MEG. These low-level
% functions are contained in the private subdirectory. These other
% toolboxes on which the framework depends are copyrighted by their
% respective authors, see each individual matlab file for the details.

% $Log: Contents.m,v $
% Revision 1.6  2004/02/04 14:00:13  roberto
% added Jens to authors and included his functions
%
% Revision 1.5  2004/01/27 10:20:08  roberto
% added combineplanar
%
% Revision 1.4  2004/01/21 16:09:03  roberto
% updated documentation
%
% Revision 1.3  2004/01/14 10:34:21  roberto
% added Markus Siegels functions and listed him as author
%
% Revision 1.2  2003/11/28 21:37:26  roberto
% updated help and function list
%
% Revision 1.1  2003/11/07 16:20:14  roberto
% updated contents with new functions
%

