function [artfctdef, artifact] = artifact_feedback(cfg,z_tdata,artfctchn,flag);

% ARTIFACT_FEEDBACK provides feedback about the artifacts in the data.
%
% [artfctdef, artifact] = artifact_feedback(cfg,artfctdef,artifact,z_tdata,artfctchn);
% If cfg.artfctdef.xxx.feedback was set to 'yes', the function updates the artifact-definition
% parameters and outputs artifact. artifact is a binary vector as a function of time (in samples).
% Its value is 1 if in one of the channels to be analysed an xxx artifact
% is present. artifact is computed by thresholding the vector z_tdata, and
% convolving this result with an appropriate artifact-kernel.
% The rejection threshold can be set interactively, while given feedback about the to
% be rejected epochs. This can be done, until the threshold is set in a satisfactory way.
%
% Copyright (c) 2003,  F.C. Donders Centre
%
% $Log: artifact_feedback.m,v $
% Revision 1.2  2005/02/08 08:36:55  jansch
% fixed bug in handling of non-padded data
%
% Revision 1.1  2005/02/07 15:10:50  roboos
% moved two subfunctions for artifact detection from main to private directory
%
% Revision 1.4  2004/09/01 09:39:28  jansch
% *** empty log message ***
%
% Revision 1.3  2004/09/01 09:27:25  jansch
% fixed some small bugs, and inconsistencies. replaced convolution with fft-convolution in the merging of artifacts, closely related in time. added GUI in artifact_viewer
%

if     strcmp(flag,'muscle'),    artfctdef = cfg.artfctdef.muscle; 
elseif strcmp(flag,'jump'),      artfctdef = cfg.artfctdef.jump;
elseif strcmp(flag,'EOGraw') | strcmp(flag,'EOGflt') | strcmp(flag,'EOG') ,artfctdef = cfg.artfctdef.eog;
end;

hdr       = read_fcdc_header(cfg.headerfile);
rejectall = zeros(1,cfg.trl(end,2));
[artifact,rejectall] = convolve_suprathreshold(cfg,artfctdef,z_tdata,hdr.Fs);

if strcmp(artfctdef.feedback,'yes') | strcmp(artfctdef.feedback,'flt')
	
	trl    = cfg.trl;
	numtrl = size(trl,1);
	accept = 0; 
	
	while accept == 0 ,         
           h = figure;
           plot(z_tdata);
           hold on;
           plot([1 length(z_tdata)],[artfctdef.cutoff artfctdef.cutoff],'r:');
           hold off;
   	
           response = input('\nwould you like to page through the data (y/n) ?\n','s');
           switch response
           case 'y'
               close(h);
               artifact_viewer(cfg,artfctdef,rejectall,z_tdata,artfctchn,flag);
           end;
   	
           fprintf(strcat('\ncurrent  ',artfctdef.method,' threshold = %1.3f'),artfctdef.cutoff);
           response = input('\nkeep the current value (y/n) ?\n','s');
           switch response
           case 'n'
               oldcutoff = artfctdef.cutoff;
               artfctdef.cutoff = input('\nenter new value \n');
   	   case 'y'
               oldcutoff = artfctdef.cutoff;
               accept = 1; 
           end;
           if oldcutoff ~= artfctdef.cutoff,
   	      rejectall = zeros(1,cfg.trl(end,2));
   	      [artifact,rejectall] = convolve_suprathreshold(cfg,artfctdef,z_tdata,hdr.Fs);
           end
           close;
	end;
end;

function [artifact, datind] = convolve_suprathreshold(cfg,artfctdef,z_tdata,Fs);

fprintf('\nidentifying artifact-epochs\n');

trl    = cfg.trl;
presmp = max([round(artfctdef.pretim .* Fs) 1]);
pstsmp = round(artfctdef.psttim .* Fs);
maxsmp = max([presmp,pstsmp]);
kernel = [zeros(1,maxsmp - presmp) ones(1,presmp) ...
          ones(1,pstsmp) zeros(1,maxsmp - pstsmp)];
krnsmp = length(kernel);
datsmp = size(z_tdata,2);
datind = zeros(size(z_tdata));
datind = sum(z_tdata>artfctdef.cutoff,1);
%datind = (conv(datind,kernel))>0;

%do an fft-convolution
fftsmp = pow2(nextpow2(datsmp+krnsmp-1));
fftdat = fft(datind,fftsmp);
fftkrn = fft(kernel,fftsmp);
datind = round(real(ifft(fftdat.*fftkrn,fftsmp)));
datind = datind(1:1:datsmp+krnsmp-1)>0;
datind(1:round((krnsmp-1)/2))=[];

begsmp = (find(diff([0 datind])==1))';
endsmp = (find(diff([datind 0])==-1))';

if ~isempty(begsmp) & ~isempty(endsmp),
    artifact(:,1) = begsmp;
    artifact(:,2) = endsmp;
else
    artifact = [];
end;

