function [pnt,tri]=head_surf(vol,grad);

% HEAD_SURF determines the head surface for a multisphere MEG headmodel
% and returns a triangulation
% 
% [pnt, tri] = head_surf(vol, grad) 
%
% where
%   grad	gradiometer definition
%   vol		multisphere volume conductor definition
%
% The head surface triangulation can be used in combination with
% find_inside_vol to determine which voxels of a beamformer scan 
% are located within the head (region of interest).

% Copyright (C) Jan-Matthijs Schoffelen
%
% $Log: head_surf.m,v $
% Revision 1.5  2004/01/26 09:03:12  roberto
% replaced complex 2x2D delaunay with single 3D convex hull triangulation
% better coverage of inferio-frontal region
%
% Revision 1.4  2003/11/03 14:43:25  roberto
% included search for matching labels in volume and gradiometer
%
% Revision 1.3  2003/10/07 10:43:02  roberto
% head surface is now only computed from M channels and not reference channels
%
% Revision 1.2  2003/06/03 08:30:32  roberto
% *** empty log message ***
%
% Revision 1.1  2003/04/17 14:57:32  roberto
%

%first determine the indices of the relevant gradiometers.
[sel_g, sel_v] = match_str(grad.label, vol.label);

%create head-surface points from multisphere head-model.
dir     = grad.pnt(sel_g,:) - vol.o(sel_v,:);
dist    = sqrt(sum(dir.*dir,2));
pnt     = repmat((vol.r(sel_v)./dist),1,3).*dir + vol.o(sel_v,:);

%  make a triangularization that is needed to find the rim of the helmet
prj    = elproj(pnt);
tri    = delaunay(prj(:,1),prj(:,2));

% find the lower rim of the helmet shape
[pnt,line] = find_mesh_edge(pnt, tri);
edgeind    = unique(line(:));

% shift the edge downwardly with an amount equal to the distance between sensor 1 and 2.
dist = sum((pnt(1,:)-pnt(2,:)).^2).^0.5;
pnt(edgeind,3) = pnt(edgeind,3) - dist; 

% use matlab triangulation algorithm to determine convex hull, this is the
% final triangulation which makes a nice headshape
tri = convhulln(pnt);
