function type = megsystem(grad)

% MEGSYSTEM returns a string that describes the manufacturer of the system
% and the type of MEG sensors
% 
% Use as
%   [str] = megsystem(grad)
% where the input is a gradiometer structure and the output will be any of
%   'ctf151'
%   'ctf275'
%   'ctf151_planar'
%   'ctf275_planar'
%   'neuromag122'
%   'neuromag306'

% the heuristic approach is to test the gradiometer definition on a few ascpects
% and score points for each of them. The system that is most "similar" wins

description = {
  'CTF151'
  'CTF275'
  'CTF151_planar'
  'CTF275_planar'
  'Neuromag122'
  'Neuromag306'
};
similar = zeros(size(description));

% look at the number of channels
Nchan = length(grad.label);
similar(1) = similar(1) + abs(Nchan-151)<10;
similar(2) = similar(2) + abs(Nchan-275)<10;
similar(3) = similar(3) + abs(Nchan-151*2)<10;
similar(4) = similar(4) + abs(Nchan-275*2)<10;
similar(5) = similar(5) + abs(Nchan-122)<10;
similar(6) = similar(6) + abs(Nchan-306)<10;

% look at the beginning of CTF channel names
similar(5) = similar(5) + length(find(strmatch('MEG', grad.label)));
similar(6) = similar(6) + length(find(strmatch('MEG', grad.label)));

% look at the beginning of CTF channel names
similar(1) = similar(1) + length(find(strmatch('MZ', grad.label)));
similar(2) = similar(2) + length(find(strmatch('MZ', grad.label)));
similar(3) = similar(3) + length(find(strmatch('MZ', grad.label)));
similar(4) = similar(4) + length(find(strmatch('MZ', grad.label)));

% look at whether the names contain _dH and _dV
similar(3) = similar(3) + length(find(strmatch('_dH', grad.label)));
similar(3) = similar(3) + length(find(strmatch('_dV', grad.label)));
similar(4) = similar(4) + length(find(strmatch('_dH', grad.label)));
similar(4) = similar(4) + length(find(strmatch('_dV', grad.label)));

% see which MEG type is the most similar
[m, i] = max(similar);
if m==0 | length(find(similar==m))>1
  error('could not detect the type of MEG system');
else
  type = description{i};
end
  
