function p = tp(t,v);

%TCDF   Student's T cumulative distribution function (cdf).
%   P = TCDF(X,V) computes the cdf for Student's T distribution
%   with V degrees of freedom, at the values in X. V must be a 
%   scalar.
%
% This is an alternative to the TCDF function that is implemented 
% in the Matlab statistics toolbox. This version originates from
% http://www.statsci.org/matlab/statbox.html and originally was called TP.
% It has been renamed to TCDF for drop-in compatibility with the Matlab
% version.
%
% Gordon Smyth, University of Queensland, gks@maths.uq.edu.au
% 3 Apr 97
%
% NaN compatible and cases where df = 1 are excluded - Markus Bauer, FCDC
% 27 Jan 2005

if v <= 0, error('Degrees of freedom must be positive.'); end;

%check for NaN's and one-sample-values - don't do calculations on them, give those out as NaNs
siz = size(t);
indices = zeros(siz);
dum = indices+isnan(t)+isnan(v)+(v<=1); %throw out
dum(dum>0) = 1;
correct = find(dum==0);

x = t(correct).^2 ./ (v(correct) + t(correct).^2) ;
p = 0.5 .* ( 1 + sign(t(correct)) .* betainc( x, 0.5, 0.5*v(correct) ) ) ;

pp = ones(siz)*NaN;
pp(correct) = p;
p = pp; clear pp;
