function [Hf,Hs,Hp] = ctf_channel_plot(ctf,surf,CHAN,FIG)

% ctf_channel_plot - plot ctf.sensor data
%
% [Hf,Hs,Hp] = ctf_channel_plot(ctf [,surf][,CHAN][,FIG])
%
% ctf  - a struct returned by ctf_read
% surf - a surface tesselation struct, surf.vertices and surf.faces;
%        the default is a convex hull of the sensor locations
% CHAN - see ctf_channel_select for options (default = 'meg')
% FIG  - figure handle to plot into (create a new figure, by default)
%
% Hf - handle to the figure
% Hs - handle to scatter plot objects
% Hp - handle to surf patch object
%
% All inputs, except ctf, are optional.  An empty input [] will be replaced
% with the default.
%
%      <>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
%      <                                                      >
%      <                    DISCLAIMER:                       >
%      <                                                      >
%      < THIS PROGRAM IS INTENDED FOR RESEARCH PURPOSES ONLY. >
%      < THIS PROGRAM IS IN NO WAY INTENDED FOR CLINICAL OR   >
%      <                    OFFICIAL USE.                     >
%      <                                                      >
%      <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<>
%

% $Revision: 1.6 $ $Date: 2005/08/03 18:57:13 $

% Copyright (C) 2004  Darren L. Weber
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% Modified: 05/2004, Darren.Weber_at_radiology.ucsf.edu
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if ~exist('ctf','var'), error('no ctf input'); end
if isempty(ctf), error('no ctf input'); end

if ~exist('CHAN','var'), CHAN = 'meg'; end
if isempty(CHAN), CHAN = 'meg'; end

if ~exist('FIG','var'), FIG = figure; end
if isempty(FIG), FIG = figure; end

usesurf = 1; % assume input surf
if ~exist('surf','var'), usesurf = 0; end
if isempty(surf), usesurf = 0; end

% This function calls ctf_channel_select
[CHAN,type] = ctf_channel_select(ctf,CHAN);

ver = '$Revision: 1.6 $ $Date: 2005/08/03 18:57:13 $';
fprintf('\nCTF_CHANNEL_PLOT [v %s]\n',ver(11:15));

sensors.vertices = zeros(length(CHAN),3);
for i = 1:length(CHAN),
    sensors.vertices(i,:) = ctf.sensor.info(CHAN(i)).location(:,1)';
end


% plot the surf patch
if ~usesurf,
    surf.vertices = sensors.vertices;
    surf.faces = convhulln(surf.vertices);
end
Nvert = length(surf.vertices);
skinRGB = [1.0, 0.9, 0.95];
fcolor = ones(Nvert,1) * skinRGB;
Hp = patch('faces',surf.faces,'vertices',surf.vertices,...
    'facecolor','interp', 'FaceVertexCData', fcolor,...
    'edgecolor', 'none',...
    'facealpha',0.4);

% plot the sensor cloud
Hf = figure(FIG); hold on
set(Hf,'Renderer','OpenGL')
Hs = scatter3(sensors.vertices(:,1),sensors.vertices(:,2),sensors.vertices(:,3),'bo','filled');

% view parameters
daspect([1 1 1]);
view([40,30]); axis tight
grid;
lighting phong; 
camlight
rotate3d on


% The CTF MEG Head Coordinate System has +X anterior, +Y left, +Z superior
xlabel('x (cm)')
ylabel('y (cm)')
zlabel('z (cm)')

return
